/* src/config_coinmp.h.  Generated by configure.  */
/* src/config_cbc.h.in. */

/* Version number of project */
#define COINMP_VERSION "1.8.4"

/* Major Version number of project */
#define COINMP_VERSION_MAJOR 1

/* Minor Version number of project */
#define COINMP_VERSION_MINOR 8

/* Release Version number of project */
#define COINMP_VERSION_RELEASE 4
